@@ -14,11 +14,15 @@ import zlib
 
 import _damo_fmt_str
 import _damo_subproc
+import _damo_sysinfo
 import _damon
 import _damon_args
 import damo_report_access
 
-PERF = 'perf'
+traceevent_damon_aggregated = 'damon_aggregated'
+traceevent_damon_monitor_intervals_tune = 'damon_monitor_intervals_tune'
+traceevent_damos_before_apply = 'damos_before_apply'
+
 perf_event_damon_aggregated = 'damon:damon_aggregated'
 perf_event_damon_monitor_intervals_tune = 'damon:damon_monitor_intervals_tune'
 perf_event_damos_before_apply = 'damon:damos_before_apply'
@@ -396,11 +400,11 @@ def record_of(target_id, records, intervals):
     records.append(record)
     return record
 
-def parse_damon_aggregated_perf_script_fields(fields):
+def parse_damon_trace_aggregated(fields):
     '''
-    The line is like below:
+    The fields is like below:
 
-    kdamond.0  4452 [000] 82877.315633: damon:damon_aggregated: \
+    82877.315633: damon:damon_aggregated: \
             target_id=18446623435582458880 nr_regions=17 \
             140731667070976-140731668037632: 0 3
 
@@ -409,17 +413,17 @@ def parse_damon_aggregated_perf_script_fields(fields):
     [1] https://lore.kernel.org/linux-mm/df8d52f1fb2f353a62ff34dc09fe99e32ca1f63f.1636610337.git.xhao@linux.alibaba.com/
     '''
 
-    if not len(fields) in [9, 10]:
+    if not len(fields) in [6, 7]:
         return None, None, None, None
 
-    end_time = int(float(fields[3][:-1]) * 1000000000)
-    target_id = int(fields[5].split('=')[1])
-    nr_regions = int(fields[6].split('=')[1])
+    end_time = int(float(fields[0][:-1]) * 1000000000)
+    target_id = int(fields[2].split('=')[1])
+    nr_regions = int(fields[3].split('=')[1])
 
-    start_addr, end_addr = [int(x) for x in fields[7][:-1].split('-')]
-    nr_accesses = int(fields[8])
-    if len(fields) == 10:
-        age = int(fields[9])
+    start_addr, end_addr = [int(x) for x in fields[4][:-1].split('-')]
+    nr_accesses = int(fields[5])
+    if len(fields) == 7:
+        age = int(fields[6])
     else:
         age = None
     region = _damon.DamonRegion(start_addr, end_addr, nr_accesses,
@@ -427,82 +431,109 @@ def parse_damon_aggregated_perf_script_fields(fields):
 
     return region, end_time, target_id, nr_regions
 
-def parse_damos_before_apply_perf_script_fields(fields):
+def parse_damos_trace_before_apply(fields):
     '''
-    The line is like below:
+    The fields would be in format of
 
-    kdamond.0  4452 [000] 82877.315633: damon:damon_aggregated: \
-            target_id=18446623435582458880 nr_regions=17 \
-            140731667070976-140731668037632: 0 3
-
-    Note that the last field is not in the early version[1].
-
-    line is like below for damos_before_apply:
-
-    kdamond.0 47293 [000] 80801.060214: damon:damos_before_apply: \
+    80801.060214: damon:damos_before_apply: \
             ctx_idx=0 scheme_idx=0 target_idx=0 nr_regions=11 \
             121932607488-135128711168: 0 136
-
-    [1] https://lore.kernel.org/linux-mm/df8d52f1fb2f353a62ff34dc09fe99e32ca1f63f.1636610337.git.xhao@linux.alibaba.com/
     '''
 
-    if len(fields) != 12:
+    if len(fields) != 9:
         return None, None, None, None
 
-    end_time = int(float(fields[3][:-1]) * 1000000000)
-    target_id = int(fields[7].split('=')[1])
-    nr_regions = int(fields[8].split('=')[1])
+    end_time = int(float(fields[0][:-1]) * 1000000000)
+    target_id = int(fields[4].split('=')[1])
+    nr_regions = int(fields[5].split('=')[1])
 
-    start_addr, end_addr = [int(x) for x in fields[9][:-1].split('-')]
-    nr_accesses = int(fields[10])
-    age = int(fields[11])
+    start_addr, end_addr = [int(x) for x in fields[6][:-1].split('-')]
+    nr_accesses = int(fields[7])
+    age = int(fields[8])
     region = _damon.DamonRegion(start_addr, end_addr, nr_accesses,
             _damon.unit_samples, age, _damon.unit_aggr_intervals)
 
     return region, end_time, target_id, nr_regions
 
-def parse_perf_script_line(line):
+def parse_damon_trace_region(fields):
     '''
-    line could be that for damon_aggregated or damos_before_apply events
+    fields could be that for damon_aggregated or damos_before_apply events
+
+    The fields would be in format of
+
+    <timestamp> <tracepoint name> ...
     '''
-    fields = line.strip().split()
-    if not len(fields) > 5:
+    if len(fields) < 2:
         return None, None, None, None
-    traceevent = fields[4][:-1]
-    if traceevent == perf_event_damon_aggregated:
-        return parse_damon_aggregated_perf_script_fields(fields)
-    elif traceevent == perf_event_damos_before_apply:
-        return parse_damos_before_apply_perf_script_fields(fields)
+    traceevent = fields[1][:-1]
+    if traceevent in [traceevent_damon_aggregated,
+                      perf_event_damon_aggregated]:
+        return parse_damon_trace_aggregated(fields)
+    elif traceevent in [traceevent_damos_before_apply,
+                        perf_event_damos_before_apply]:
+        return parse_damos_trace_before_apply(fields)
     else:
         return None, None, None, None
 
-def parse_perf_script_tune_line(line):
+def parse_damon_trace_intervals_tune(fields):
     '''
-    The line is in format of, e.g.,
-    35359.794 kdamond.0/57030 damon:damon_monitor_intervals_tune(sample_us: 100000)
+    Example fields:
+
+    ['92713.218210:', 'damon:damon_monitor_intervals_tune:', 'sample_us=80000']
 
     Return if the line is for damon_monitor_intervals_tune, and if so, the
     sample_us value.
      '''
+    if len(fields) != 3:
+        return False, None
+    tracepoint_name = fields[1][:-1]
+    if not tracepoint_name in [traceevent_damon_monitor_intervals_tune,
+                               perf_event_damon_monitor_intervals_tune]:
+        return False, None
+    return True, int(fields[2].split('=')[1])
 
+def damon_trace_fields(line):
+    '''
+    Receives a line from 'trace-cmd report' or 'perf script' outputs and return
+    fields starting from the timestamp (the fourth field).
+
+    In case of trace-cmd report, the format is like,
+
+           kdamond.0-264454 [007] ..... 92627.258073: damon_aggregated: \
+                   target_id=0 nr_regions=10 8255430656-8372879360: 0 1
+
+    In case of perf script, the format is like,
+
+            kthreadd  264573 [003] 93212.176071: damon:damon_aggregated: \
+                    target_id=0 nr_regions=4 6945607680-8372879360: 0 0
+
+    The format from the fourth field is identical for both cases, and hence a
+    single parsing logic can be used.
+    '''
     fields = line.split()
-    if len(fields) != 4:
-        return False, None
-    tracepoint_name = fields[2].split('(')[0]
-    if tracepoint_name != perf_event_damon_monitor_intervals_tune:
-        return False, None
-    return True, int(fields[3].split(')')[0])
+    if len(fields) < 4:
+        return None
+    return fields[3:]
 
-def parse_perf_script(script_output, monitoring_intervals):
+def parse_damon_trace(trace_text, monitoring_intervals):
+    '''
+    Parse DAMON tracepoints.  trace_text could be output of 'perf script' or
+    'trace-cmd report'.
+    '''
     records = []
     snapshot = None
     snapshot_sample_interval_us = None
 
-    for line in script_output.split('\n'):
-        parsed, snapshot_sample_interval_us = parse_perf_script_tune_line(line)
+    for line in trace_text.split('\n'):
+        fields = damon_trace_fields(line)
+        if fields is None:
+            continue
+        parsed, snapshot_sample_interval_us = parse_damon_trace_intervals_tune(
+                fields)
         if parsed is True:
             continue
-        region, end_time, target_id, nr_regions = parse_perf_script_line(line)
+        region, end_time, target_id, nr_regions = parse_damon_trace_region(
+                fields)
         if region is None:
             continue
 
@@ -533,23 +564,21 @@ def parse_perf_script(script_output, monitoring_intervals):
     set_first_snapshot_start_time(records)
     return records, None
 
-def set_perf_path(perf_path):
-    global PERF
-    PERF = perf_path
-
-    # Test perf record for damon event
-    err = None
-    if _damo_subproc.avail_cmd(PERF):
-        try:
-            subprocess.check_output(
-                    [PERF, 'record', '-e', perf_event_damon_aggregated, '--',
-                        'sleep', '0'],
-                    stderr=subprocess.PIPE)
-        except:
-            err = 'perf record not working with "%s"' % PERF
-    else:
-        err = 'perf not found at "%s"' % PERF
-    return err
+def parse_perf_damon_record(
+        record_file, monitoring_intervals, perf_cmd='perf'):
+    '''Returns DamonRecord list and error'''
+    try:
+        with open(os.devnull, 'w') as fnull:
+            # in some setup, perf record file ends up having no proper
+            # ownership.  There's no reason to be strict about that from
+            # damo.  As long as we can, just parse it with '--force'
+            # option.
+            perf_script_output = subprocess.check_output(
+                    [perf_cmd, 'script', '--force', '-i', record_file],
+                    stderr=fnull).decode()
+    except Exception as e:
+        return None, 'failed perf-script (%s)' % e
+    return parse_damon_trace(perf_script_output, monitoring_intervals)
 
 def parse_json(json_str):
     kvpairs = json.loads(json_str)
@@ -587,28 +616,13 @@ def parse_records_file(record_file, monitoring_intervals=None):
         except Exception as e:
             return None, 'failed parsing json compressed file (%s)' % e
 
-    perf_script_output = None
     if file_type == 'ASCII text':
         with open(record_file, 'r') as f:
             perf_script_output = f.read()
-    else:
-        # might be perf data
-        try:
-            with open(os.devnull, 'w') as fnull:
-                # in some setup, perf record file ends up having no proper
-                # ownership.  There's no reason to be strict about that from
-                # damo.  As long as we can, just parse it with '--force'
-                # option.
-                perf_script_output = subprocess.check_output(
-                        [PERF, 'script', '--force', '-i', record_file],
-                        stderr=fnull).decode()
-        except:
-            # Should be record format file
-            pass
-    if perf_script_output is not None:
-        return parse_perf_script(perf_script_output, monitoring_intervals)
-    else:
-        return None, 'parsing %s failed' % record_file
+        return parse_damon_trace(perf_script_output, monitoring_intervals)
+
+    return parse_perf_damon_record(
+            record_file, monitoring_intervals, perf_cmd='perf')
 
 # for writing monitoring results to a file
 
@@ -702,18 +716,34 @@ def write_damon_records(records, file_path, file_type, file_permission=None):
         os.chmod(file_path, file_permission)
     return None
 
-def rewrite_record_file(src_file, dst_file, file_format, file_permission=None,
-        monitoring_intervals=None):
-    records, err = parse_records_file(src_file, monitoring_intervals)
+def convert_perf_to_damon_data(
+        src_file, dst_file, file_format, file_permission=None,
+        monitoring_intervals=None, perf_cmd='perf'):
+    if file_format == file_type_perf_data:
+        os.chmod(file_path, handle.file_permission)
+        return None
+
+    records, err = parse_perf_damon_record(
+            src_file, monitoring_intervals, perf_cmd=perf_cmd)
     if err:
         return err
     return write_damon_records(records, dst_file, file_format,
             file_permission)
 
-def update_records_file(file_path, file_format, file_permission=None,
-        monitoring_intervals=None):
-    return rewrite_record_file(file_path, file_path, file_format,
-            file_permission, monitoring_intervals)
+def convert_trace_cmd_to_damon_data(
+        file_path, file_format, file_permission, monitoring_intervals):
+    try:
+        with open(os.devnull, 'w') as fnull:
+            output = subprocess.check_output(
+                    ['trace-cmd', 'report', '-i', file_path],
+                    stderr=fnull).decode()
+    except Exception as e:
+        return 'trace-cmd report fail (%s)' % e
+    records, err = parse_damon_trace(output, monitoring_intervals)
+    if err:
+        return 'trace-cmd output parsing fail (%s)' % err
+    return write_damon_records(records, file_path, file_format,
+                               file_permission)
 
 # for recording
 
@@ -1108,10 +1138,14 @@ class RecordingHandle:
     file_format = None
     file_permission = None
 
+    # for custom perf
+    perf_path = None
+
     # for access patterns tracing
     tracepoints = None
     monitoring_intervals = None
-    perf_pipe = None
+    damon_tracer_pipe = None
+    damon_tracer = None
 
     # for access patterns snapshot
     snapshot_request = None # SnapshotRequest object.
@@ -1152,7 +1186,8 @@ class RecordingHandle:
                  kdamonds, add_child_tasks, record_mem_footprint,
                  record_vmas, record_proc_stats, timeout, snapshot_request,
                  snapshot_interval_sec, snapshot_count,
-                 max_seconds_per_file=3600):
+                 max_seconds_per_file=3600, damon_tracer='perf'):
+        self.damon_tracer = damon_tracer
         self.tracepoints = tracepoints
         self.file_path = file_path
         self.file_format = file_format
@@ -1184,30 +1219,33 @@ class RecordingHandle:
             return False
         return True
 
-def tracepoint_supported(tracepoint):
-    output = subprocess.check_output(
-            [PERF, 'list', 'tracepoint']).decode().strip()
-    for line in output.split('\n'):
-        fields = line.split()
-        if len(fields) < 3:
-            continue
-        if fields[1:3] != ['[Tracepoint', 'event]']:
-            continue
-        if fields[0] == tracepoint:
-            return True
-    return False
+    def set_perf_path(self, perf_path):
+        if not _damo_subproc.avail_cmd(perf_path):
+            return 'perf not found at "%s"' % perf_path
+        self.perf_path = perf_path
+        return None
+
+def start_damon_tracing(handle):
+    perf_cmd = 'perf'
+    if handle.perf_path is not None:
+        perf_cmd = handle.perf_path
 
-def start_recording_perf(handle):
     if handle.tracepoints is not None:
         tracepoints_option = []
         for tracepoint in handle.tracepoints:
-            if tracepoint_supported(tracepoint):
+            if _damo_sysinfo.damon_tracepoint_available(tracepoint):
                 tracepoints_option += ['-e', tracepoint]
-        handle.perf_pipe = subprocess.Popen(
-                [PERF, 'record', '-a', '-o', handle.file_path] +
-                tracepoints_option)
+        if handle.damon_tracer == 'perf':
+            handle.damon_tracer_pipe = subprocess.Popen(
+                    [perf_cmd, 'record', '-a', '-o', handle.file_path] +
+                    tracepoints_option)
+        elif handle.damon_tracer == 'trace-cmd':
+            handle.damon_tracer_pipe = subprocess.Popen(
+                    ['trace-cmd', 'record', '-o', handle.file_path] +
+                    tracepoints_option,
+                    stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL)
     if handle.do_profile:
-        cmd = [PERF, 'record', '-o', '%s.profile' % handle.file_path]
+        cmd = [perf_cmd, 'record', '-o', '%s.profile' % handle.file_path]
         handle.perf_profile_pipe = subprocess.Popen(cmd)
 
 def record_source_is_running(record_handle):
@@ -1217,7 +1255,7 @@ def record_source_is_running(record_handle):
             _damon.any_kdamond_running()
 
 def start_recording(handle):
-    start_recording_perf(handle)
+    start_damon_tracing(handle)
 
     start_time = time.time()
     last_output_saved_time = start_time
@@ -1257,7 +1295,7 @@ def start_recording(handle):
                 handle.proc_stats = []
             if handle.snapshot_records is not None:
                 handle.snapshot_records = []
-            start_recording_perf(handle)
+            start_damon_tracing(handle)
 
         if handle.snapshot_request:
             if handle.snapshot_records is None:
@@ -1287,23 +1325,32 @@ def save_recording_outputs(handle, file_path):
         json.dump([k.to_kvpairs() for k in handle.kdamonds], f, indent=4)
     os.chmod(kdamonds_file_path, handle.file_permission)
 
-    if handle.perf_pipe:
+    if handle.damon_tracer_pipe:
         try:
-            handle.perf_pipe.send_signal(signal.SIGINT)
-            handle.perf_pipe.wait()
+            handle.damon_tracer_pipe.send_signal(signal.SIGINT)
+            handle.damon_tracer_pipe.wait()
         except:
             # perf might already finished
             pass
         os.rename(handle.file_path, file_path)
 
-        if handle.file_format == file_type_perf_data:
-            os.chmod(file_path, handle.file_permission)
-        else:
-            err = update_records_file(file_path, handle.file_format,
-                    handle.file_permission, handle.monitoring_intervals)
+        if handle.damon_tracer == 'perf':
+            perf_cmd = 'perf'
+            if handle.perf_path is not None:
+                perf_cmd = handle.perf_path
+            err = convert_perf_to_damon_data(
+                    src_file=file_path, dst_file=file_path,
+                    file_format=handle.file_format,
+                    file_permission=handle.file_permission,
+                    monitoring_intervals=handle.monitoring_intervals,
+                    perf_cmd=perf_cmd)
             if err is not None:
                 print('converting format from perf_data to %s failed (%s)' %
                         (handle.file_format, err))
+        if handle.damon_tracer == 'trace-cmd':
+            err = convert_trace_cmd_to_damon_data(
+                    file_path, handle.file_format, handle.file_permission,
+                    handle.monitoring_intervals)
 
     if handle.snapshot_records:
         write_damon_records(handle.snapshot_records, file_path,
@@ -1368,7 +1415,8 @@ def find_install_scheme(scheme_to_find):
             ctx_has_the_scheme = False
             for sidx, scheme in enumerate(ctx.schemes):
                 if scheme.effectively_equal(scheme_to_find, ctx.intervals):
-                    if _damon.feature_supported('schemes_apply_interval'):
+                    if _damo_sysinfo.damon_feature_available(
+                            'sysfs/schemes_apply_interval'):
                         scheme_to_find.apply_interval_us = ctx.intervals.sample
                     ctx_has_the_scheme = True
                     indices.append([kidx, cidx, sidx])
@@ -1376,7 +1424,8 @@ def find_install_scheme(scheme_to_find):
             if ctx_has_the_scheme:
                 continue
 
-            if _damon.feature_supported('schemes_apply_interval'):
+            if _damo_sysinfo.damon_feature_available(
+                    'sysfs/schemes_apply_interval'):
                 scheme_to_find.apply_interval_us = ctx.intervals.sample
             ctx.schemes.append(scheme_to_find)
             installed = True
@@ -1769,7 +1818,8 @@ def get_snapshot_records_of(request):
             access_pattern = request.record_filter.access_pattern
 
             addr_ranges = request.record_filter.address_ranges
-            if addr_ranges and _damon.feature_supported('schemes_filters_addr'):
+            if addr_ranges and _damo_sysinfo.damon_feature_available(
+                    'sysfs/schemes_filters_addr'):
                 for start, end in addr_ranges:
                     filters.append(_damon.DamosFilter(
                         'addr', False,
@@ -1862,9 +1912,9 @@ def get_records(tried_regions_of=None, record_file=None,
                 total_sz_only=False, dont_merge_regions=True):
     # If record is live snapshot, access pattern filtering is applied with
     # get_snapshot_records_of() because it uses DAMOS to get the snapshot.  If
-    # the kernel has schemes_filters_addr feature, address ranges filter is
-    # also applied.  Also, snapshot time range filter makes no sense for live
-    # snapshot.
+    # the kernel has sysfs/schemes_filters_addr feature, address ranges filter
+    # is also applied.  Also, snapshot time range filter makes no sense for
+    # live snapshot.
     # To avoid confusing caller, copy filter, modify the filter as necessary
     # and apply only necessary filters at once at last stage.
     if record_filter:
@@ -1880,7 +1930,7 @@ def get_records(tried_regions_of=None, record_file=None,
         if err is not None:
             return None, err
         filter_copy.access_pattern = None
-        if _damon.feature_supported('schemes_filters_addr'):
+        if _damo_sysinfo.damon_feature_available('sysfs/schemes_filters_addr'):
             filter_copy.address_ranges = None
             filter_copy.snapshot_time_ranges = None
     else:
