@@ -421,6 +421,8 @@ class DamonAge:
     def to_str(self, unit, raw):
         if unit == unit_usec:
             return _damo_fmt_str.format_time_us_exact(self.usec, raw)
+        if self.aggr_intervals is None:
+            return 'unkown %s' % unit_aggr_intervals
         return '%s %s' % (_damo_fmt_str.format_nr(self.aggr_intervals, raw),
                 unit_aggr_intervals)
 
@@ -489,8 +491,7 @@ class DamonRegion:
         return self.to_str(False)
 
     def __eq__(self, other):
-        if self.nr_accesses == None:
-            return type(self) == type(other) and '%s' % self == '%s' % other
+        return type(self) == type(other) and '%s' % self == '%s' % other
 
     # For aggregate_snapshots() support
     def __hash__(self):
@@ -1546,19 +1547,6 @@ def ensure_root_permission():
         print('Run as root')
         exit(1)
 
-def feature_supported(feature):
-    sysinfo, err = _damo_sysinfo.get_sysinfo()
-    if err is not None:
-        raise Exception(
-        'BUG.  Please report on https://github.com/damonitor/damo/issues')
-    if _damon_fs == _damon_sysfs:
-        return feature in [f.name for f in sysinfo.avail_damon_sysfs_features]
-    else:
-        return feature in [
-                f.name for f in sysinfo.avail_damon_debugfs_features]
-    raise Exception(
-            'BUG.  Please report on https://github.com/damonitor/damo/issues')
-
 def set_damon_interface(damon_interface):
     global _damon_fs
     if damon_interface == 'sysfs':
@@ -1690,7 +1678,8 @@ def update_schemes_tried_bytes(kdamond_idxs=None):
     return _damon_fs.update_schemes_tried_bytes(kdamond_idxs)
 
 def update_schemes_tried_regions(kdamond_idxs=None):
-    if not feature_supported('schemes_tried_regions'):
+    if not _damo_sysinfo.damon_feature_available(
+            'sysfs/schemes_tried_regions'):
         return 'DAMON feature \'schemes_tried_regions\' is not supported' \
                 ' on the current kernel.  ' \
                 'It is available on kernel version 6.2 and later'
@@ -1724,12 +1713,14 @@ def update_schemes_status(stats=True, tried_regions=True,
         err = update_schemes_stats(idxs)
         if err != None:
             return err
-    if tried_regions and feature_supported('schemes_tried_regions'):
+    if tried_regions and _damo_sysinfo.damon_feature_available(
+            'sysfs/schemes_tried_regions'):
         err = update_schemes_tried_regions(idxs)
         if err != None:
             return err
 
-    if quota_effective_bytes and feature_supported('schemes_quota_effective_bytes'):
+    if quota_effective_bytes and _damo_sysinfo.damon_feature_available(
+            'sysfs/schemes_quota_effective_bytes'):
         return update_schemes_quota_effective_bytes(idxs)
 
     return None
@@ -1797,7 +1788,7 @@ def add_vaddr_child_targets(ctx):
             child_targets.append(DamonTarget(pid=child_pid, regions=[]))
             changes_made = True
     if changes_made:
-        if feature_supported('obsolete_target'):
+        if _damo_sysinfo.damon_feature_available('sysfs/obsolete_target'):
             ctx.targets = updated_targets + child_targets
         else:
             ctx.targets = best_effort_target_arrange(
