@@ -551,11 +551,8 @@ def build_sample_control_ops_attrs(args, idx):
         tids = args.exp_ops_tids[idx]
     else:
         tids = ''
-    use_sample_control, err = _damo_sysinfo.damon_sysfs_feature_available(
-            'damon_sample_control')
-    if err is not None:
-        return None, None, \
-                'damon_sample_control feature check fail (%s)' % support
+    use_sample_control = _damo_sysinfo.damon_feature_available(
+            'sysfs/damon_sample_control')
     if use_sample_control is False:
         try:
             ops_attrs = _damon.OpsAttrs(
