@@ -10,6 +10,7 @@ import _damo_deprecation_notice
 import _damo_fs
 import _damo_sysinfo
 import _damon
+import _damon_features
 
 debugfs_root = None
 
@@ -138,7 +139,8 @@ def write_schemes(dir_path, schemes, intervals):
     scheme_file_input_lines = []
     for scheme in schemes:
         scheme_file_input_lines.append(damos_to_debugfs_input(scheme,
-            intervals, feature_supported('schemes_time_quota')))
+            intervals, _damo_sysinfo.damon_feature_available(
+                'debugfs/schemes_time_quota')))
     scheme_file_input = '\n'.join(scheme_file_input_lines)
     if scheme_file_input == '':
         scheme_file_input = '\n'
@@ -153,17 +155,18 @@ def write_target(dir_path, target, target_has_pid):
             return err
         tid = target.pid
     else:
-        if not feature_supported('paddr'):
+        if not _damo_sysinfo.damon_feature_available('debugfs/paddr'):
             raise Exception('paddr is not supported')
         err = _damo_fs.write_file(
                 os.path.join(dir_path, 'target_ids'), 'paddr\n')
         if err is not None:
             return err
         tid = 42
-    if feature_supported('init_regions_target_idx'):
+    if _damo_sysinfo.damon_feature_available(
+            'debugfs/init_regions_target_idx'):
         tid = 0
 
-    if feature_supported('init_regions'):
+    if _damo_sysinfo.damon_feature_available('debugfs/init_regions'):
         string = ' '.join(['%s %d %d' % (tid, r.start, r.end) for r in
             target.regions])
         err = _damo_fs.write_file(
@@ -198,7 +201,7 @@ def write_kdamonds(dir_path, kdamonds):
                 dir_path, ctx.targets[0], _damon.target_has_pid(ctx.ops))
         if err:
             return err
-    if not feature_supported('schemes'):
+    if not _damo_sysinfo.damon_feature_available('debugfs/schemes'):
         return None
 
     err = write_schemes(dir_path, ctx.schemes, ctx.intervals)
@@ -231,7 +234,7 @@ def debugfs_schemes_output_fields_to_access_pattern(fields, intervals_us):
 
 def debugfs_output_to_damos(output, intervals_us):
     fields = [int(x) for x in output.strip().split()]
-    if feature_supported('schemes_stat_succ'):
+    if _damo_sysinfo.damon_feature_available('debugfs/schemes_stat_succ'):
         nr_stat_fields = 5
     else:
         nr_stat_fields = 2
@@ -275,7 +278,8 @@ def files_content_to_kdamonds(files_content):
     regions_dict = {}
     # Reading init_regions fails when DAMON is running.  Do the parsing only
     # when DAMON is off.
-    if state == 'off' and feature_supported('init_regions'):
+    if state == 'off' and _damo_sysinfo.damon_feature_available(
+            'debugfs/init_regions'):
         fields = [int(x) for x in files_content['init_regions'].strip().split()]
         for i in range(0, len(fields), 3):
             id_or_index = fields[i]
@@ -292,11 +296,12 @@ def files_content_to_kdamonds(files_content):
         targets.append(_damon.DamonTarget(
             pid=target_id if not is_paddr else None,
             regions=regions_dict[idx
-                if feature_supported('init_regions_target_idx')
+                if _damo_sysinfo.damon_feature_available(
+                    'debugfs/init_regions_target_idx')
                 else target_id] if len(regions_dict) > 0 else []))
 
     schemes = []
-    if feature_supported('schemes'):
+    if _damo_sysinfo.damon_feature_available('debugfs/schemes'):
         for line in files_content['schemes'].split('\n'):
             if line.strip() == '':
                 continue
@@ -320,16 +325,6 @@ def nr_kdamonds():
 
 # features
 
-def feature_supported(feature_name):
-    sysinfo, err = _damo_sysinfo.get_sysinfo()
-    if err is not None:
-        # this should be called after load_sysinfo() success.
-        raise Exception('BUG')
-    for feature in sysinfo.avail_damon_debugfs_features:
-        if feature.name == feature_name:
-            return True
-    return False
-
 def values_for_restore(filepath, read_val):
     if read_val == '':
         return '\n'
@@ -430,26 +425,26 @@ def mk_feature_supports_map():
     Read _damon_sysfs.mk_feature_supports_map() for more details.
     '''
 
-    feature_supports = {x.name: False for x in _damo_sysinfo.damon_features}
+    feature_supports = {x.name: False for x in _damon_features.features_list}
 
     need_schemes_file_test = False
     if os.path.isfile(get_schemes_file()):
-        feature_supports['schemes'] = True
+        feature_supports['debugfs/schemes'] = True
         with open(get_schemes_file(), 'r') as f:
             nr_fields = len(f.read().strip().split())
         if nr_fields == 0:
             need_schemes_file_test = True
         elif nr_fields == 20:   # v5.16
-            feature_supports['schemes_size_quota'] = True
-            feature_supports['schemes_prioritization'] = True
-            feature_supports['schemes_wmarks'] = True
-            feature_supports['schemes_time_quota'] = True
+            feature_supports['debugfs/schemes_size_quota'] = True
+            feature_supports['debugfs/schemes_prioritization'] = True
+            feature_supports['debugfs/schemes_wmarks'] = True
+            feature_supports['debugfs/schemes_time_quota'] = True
         elif nr_fields == 23:   # v5.17 or later
-            feature_supports['schemes_size_quota'] = True
-            feature_supports['schemes_prioritization'] = True
-            feature_supports['schemes_wmarks'] = True
-            feature_supports['schemes_time_quota'] = True
-            feature_supports['schemes_stat_succ'] = True
+            feature_supports['debugfs/schemes_size_quota'] = True
+            feature_supports['debugfs/schemes_prioritization'] = True
+            feature_supports['debugfs/schemes_wmarks'] = True
+            feature_supports['debugfs/schemes_time_quota'] = True
+            feature_supports['debugfs/schemes_stat_succ'] = True
             feature_supports['schemes_stat_qt_exceed'] = True
 
     if _damon.any_kdamond_running():
@@ -457,30 +452,30 @@ def mk_feature_supports_map():
                 'debugfs feature update cannot be done while DAMON running'
 
     # virtual address space has supported since the beginning
-    feature_supports['vaddr'] = True
+    feature_supports['debugfs/vaddr'] = True
     if test_debugfs_file(get_target_ids_file(), 'paddr\n', '42\n'):
-        feature_supports['paddr'] = True
+        feature_supports['debugfs/paddr'] = True
 
     if os.path.isfile(get_init_regions_file()):
-        feature_supports['init_regions'] = True
+        feature_supports['debugfs/init_regions'] = True
         init_regions_version = test_init_regions_version(
-                feature_supports['paddr'])
+                feature_supports['debugfs/paddr'])
         if init_regions_version == 2:
-            feature_supports['init_regions_target_idx'] = True
+            feature_supports['debugfs/init_regions_target_idx'] = True
 
     if need_schemes_file_test:
         # 'schemes' receives 18 numbers input and has three stats (v5.16)
         if test_debugfs_file_schemes(18):
-            feature_supports['schemes_size_quota'] = True
-            feature_supports['schemes_prioritization'] = True
-            feature_supports['schemes_wmarks'] = True
-            feature_supports['schemes_time_quota'] = True
+            feature_supports['debugfs/schemes_size_quota'] = True
+            feature_supports['debugfs/schemes_prioritization'] = True
+            feature_supports['debugfs/schemes_wmarks'] = True
+            feature_supports['debugfs/schemes_time_quota'] = True
         elif test_debugfs_file_schemes_stat_extended(18):
-            feature_supports['schemes_size_quota'] = True
-            feature_supports['schemes_prioritization'] = True
-            feature_supports['schemes_wmarks'] = True
-            feature_supports['schemes_time_quota'] = True
-            feature_supports['schemes_stat_succ'] = True
-            feature_supports['schemes_stat_qt_exceed'] = True
+            feature_supports['debugfs/schemes_size_quota'] = True
+            feature_supports['debugfs/schemes_prioritization'] = True
+            feature_supports['debugfs/schemes_wmarks'] = True
+            feature_supports['debugfs/schemes_time_quota'] = True
+            feature_supports['debugfs/schemes_stat_succ'] = True
+            feature_supports['debugfs/schemes_stat_qt_exceed'] = True
 
     return feature_supports, None
