@@ -4,6 +4,7 @@
 Record monitored data access patterns.
 """
 
+import argparse
 import json
 import os
 import signal
@@ -12,6 +13,7 @@ import time
 
 import _damo_fmt_str
 import _damo_records
+import _damo_subproc
 import _damon
 import _damon_args
 
@@ -66,11 +68,6 @@ def handle_args(args):
         if os.path.isfile(footprint_file_path):
             os.rename(footprint_file_path, footprint_file_path + '.old')
 
-    err = _damo_records.set_perf_path(args.perf_path)
-    if err != None:
-        print(err)
-        exit(-3)
-
 def tracepoints_from_args(args):
     if not 'access' in args.do_record or args.snapshot is not None:
         return None
@@ -122,8 +119,32 @@ def mk_handle(args, kdamonds, monitoring_intervals):
 
     output_flush_sec = _damo_fmt_str.text_to_sec(args.output_flush_sec)
 
+    do_records = args.do_record
+    damon_tracer = args.damon_tracer
+    if damon_tracer is not None:
+        tracer = damon_tracer
+        if tracer == 'perf' and args.perf_path is not None:
+            tracer = args.perf_path
+        if not _damo_subproc.avail_cmd(tracer):
+            print('--damon_tracer (%s) is unavailable' % tracer)
+            cleanup_exit(1)
+    else:
+        perf_path = 'perf'
+        if args.perf_path is not None:
+            perf_path = args.perf_path
+        if _damo_subproc.avail_cmd(perf_path):
+            damon_tracer = 'perf'
+        elif _damo_subproc.avail_cmd('trace-cmd'):
+            damon_tracer = 'trace-cmd'
+            if 'cpu_profile' in do_records:
+                do_records.remove('cpu_profile')
+        else:
+            print('Please install trace-cmd or perf and retry')
+            cleanup_exit(1)
+
     handle = _damo_records.RecordingHandle(
             # for access pattern monitoring
+            damon_tracer=damon_tracer,
             tracepoints=tracepoints, file_path=args.out,
             file_format=args.output_type,
             file_permission=args.output_permission,
@@ -139,6 +160,11 @@ def mk_handle(args, kdamonds, monitoring_intervals):
             snapshot_interval_sec=snapshot_interval_sec,
             snapshot_count=snapshot_count,
             max_seconds_per_file=output_flush_sec)
+    if args.perf_path is not None:
+        err = handle.set_perf_path(args.perf_path)
+        if err is not None:
+            print('--perf_path handling fail (%s)' % err)
+            cleanup_exit(1)
 
     return handle
 
@@ -211,8 +237,7 @@ def set_argparser(parser):
     parser.add_argument(
             '--output_flush_sec', type=str, default='3600',
             help='intermediate output files flush duration in seconds')
-    parser.add_argument('--perf_path', type=str, default='perf',
-                        help='path of perf tool ')
+    parser.add_argument('--perf_path', type=str, help='path of perf tool')
     parser.add_argument('--exclude_child_tasks', action='store_false',
                         dest='include_child_tasks',
                         help='do not record access of child processes')
@@ -230,6 +255,11 @@ def set_argparser(parser):
                         choices=['access', 'cpu_profile', 'mem_footprint',
                                  'vmas', 'proc_stats'],
                         help='what to do record')
+    parser.add_argument('--damon_tracer', metavar='cmd',
+                        choices=['perf', 'trace-cmd'],
+                        # tracer to use.  Hide this as this is an experimental
+                        # option.
+                        help=argparse.SUPPRESS)
     _damo_records.set_snapshot_damos_filters_option(parser)
     _damo_records.set_filter_argparser(parser)
     return parser
