@@ -61,22 +61,33 @@ class GuideInfo:
             ret += r[1] - r[0]
         return ret
 
-    def __str__(self):
-        lines = [
-                'kdamond_idx: %s' % self.kdamond_idx,
-                'context_idx: %s' % self.context_idx,
-                'scheme_idx: %s' % self.scheme_idx,
-                'target_id: %s' % self.tid]
-        lines.append('time: %d-%d (%s)' % (self.start_time, self.end_time,
-                    _damo_fmt_str.format_time_ns(self.end_time - self.start_time,
-                        False)))
+    def to_str(self, raw):
+        lines = []
+        if self.kdamond_idx is not None:
+            lines.append('kdamond_idx: %s' % self.kdamond_idx)
+        if self.context_idx is not None:
+            line.sappend('context_idx: %s' % self.context_idx)
+        if self.scheme_idx is not None:
+            lines.append('scheme_idx: %s' % self.scheme_idx)
+        if self.tid is not None:
+            lines.append('target_id: %s' % self.tid)
+        lines.append('time: [%s, %s) (%s)' % (
+            _damo_fmt_str.format_time_ns(self.start_time, raw),
+            _damo_fmt_str.format_time_ns(self.end_time, raw),
+            _damo_fmt_str.format_time_ns(
+                self.end_time - self.start_time, raw)))
         for idx, region in enumerate(self.contig_regions):
-            lines.append('region\t%2d: %020d-%020d (%s)' %
-                         (idx, region.start_addr, region.end_addr,
-                          _damo_fmt_str.format_sz(
-                              region.end_addr - region.start_addr, False)))
+            lines.append('region\t%2d: [%s, %s) (%s)' % (
+                idx,
+                _damo_fmt_str.format_sz(region.start_addr, raw),
+                _damo_fmt_str.format_sz(region.end_addr, raw),
+                _damo_fmt_str.format_sz(
+                    region.end_addr - region.start_addr, raw)))
         return '\n'.join(lines)
 
+    def __str__(self):
+        return self.to_str(raw=True)
+
 def is_overlap(region1, region2):
     if region1[1] < region2[0]:
         return False
@@ -174,9 +185,9 @@ def get_guide_info(records):
     return sorted(list(guides.values()), key=lambda x: x.total_space(),
                     reverse=True)
 
-def pr_guide(records):
+def pr_guide(records, raw_numbers=True):
     for guide in get_guide_info(records):
-        print(guide)
+        print(guide.to_str(raw_numbers))
 
 def main(args):
     records, err = _damo_records.get_records(record_file=args.input)
@@ -184,8 +195,10 @@ def main(args):
         print('monitoring result file (%s) parsing failed (%s)' %
                 (args.input, err))
         exit(1)
-    pr_guide(records)
+    pr_guide(records, args.raw_numbers)
 
 def set_argparser(parser):
-    parser.add_argument('--input', '-i', type=str, metavar='<file>',
+    parser.add_argument('--input', '-i', type=str, metavar='<file>', nargs='+',
             default='damon.data', help='input file name')
+    parser.add_argument('--raw_numbers', action='store_true',
+                        help='print numbers in raw format')
