@@ -1389,9 +1389,12 @@ def set_formats_percentiles(args, fmt, records, recency_or_temperature):
     fmt.format_region = ''
 
 def set_formats_handle_format_set_arg(fmt, format_arg):
-    '''Handle --format inputs except 'append' ones'''
+    '''
+    Apply --format inputs except 'append' ones, update fmt (ReportFormat).
+    Returns updated fmt and error if failed.
+    '''
     if format_arg is None:
-        return
+        return fmt, None
     if len(format_arg) == 1 and len(format_arg[0]) == 1:
         fmt_string = format_arg[0][0]
         if os.path.isfile(fmt_string):
@@ -1421,6 +1424,7 @@ def set_formats_handle_format_set_arg(fmt, format_arg):
                 fmt.format_snapshot_tail = fmt_string
             elif target_area == 'record_tail':
                 fmt.format_record_tail = fmt_string
+    return fmt, None
 
 def set_formats_handle_styles(fmt, args, records):
     if args.style is None:
@@ -1435,9 +1439,10 @@ def set_formats_handle_styles(fmt, args, records):
         fmt.region_box_min_max_length = [1, 40]
         fmt.region_box_align = 'right'
         fmt.region_box_colorset = 'emotion'
-    elif args.style in ['temperature-sz-hist', 'recency-sz-hist']:
+    elif args.style in ['temperature-sz-hist', 'recency-sz-hist',
+                        'cold-memory-tail']:
         set_formats_hist_style(args, fmt, records)
-    elif args.style == 'recency-percentiles':
+    elif args.style in ['recency-percentiles', 'idle-time-percentiles']:
         set_formats_percentiles(args, fmt, records, 'recency')
     elif args.style == 'temperature-percentiles':
         set_formats_percentiles(args, fmt, records, 'temperature')
@@ -1576,7 +1581,9 @@ def set_formats_handle_format_append_arg(fmt, format_args):
 def set_formats(args, records):
     fmt = ReportFormat.from_args(args)
 
-    set_formats_handle_format_set_arg(fmt, args.format)
+    fmt, err = set_formats_handle_format_set_arg(fmt, args.format)
+    if err is not None:
+        return fmt, err
     set_formats_handle_styles(fmt, args, records)
 
     if args.total_sz_only:
@@ -1787,6 +1794,7 @@ def read_and_show(args):
         fmt, err = set_formats(args, records)
         if err is not None:
             print('format setting failed (%s)' % err)
+            exit(1)
 
         if args.on_cache is not None:
             sz_cache = _damo_fmt_str.text_to_bytes(args.on_cache[0])
@@ -1816,8 +1824,13 @@ def add_fmt_args(parser, hide_help=False):
     # how to show, in simple selection
     parser.add_argument(
             '--style', choices=['detailed', 'simple-boxes',
-                                'temperature-sz-hist', 'recency-sz-hist',
-                                'recency-percentiles',
+                                'temperature-sz-hist',
+                                # cold-memory-tail is just another name of
+                                # recency-sz-hist
+                                'recency-sz-hist', 'cold-memory-tail',
+                                # idle-time-percentiles is just another name of
+                                # recency-percentiles
+                                'recency-percentiles', 'idle-time-percentiles',
                                 'temperature-percentiles',
                                 'cold', 'hot'],
             default='detailed',
