@@ -11,26 +11,37 @@ _test_damo_common.add_damo_dir_to_syspath()
 import _damo_sysinfo
 import _damon
 import _damon_args
+import _damon_features
 import _damon_sysfs
 
 def set_damon_sysfs_features():
     avail_features = []
     for name, support in {
-            'init_regions': True, 'schemes': True, 'schemes_stat_qt_exceed':
-            True, 'init_regions_target_idx': True, 'schemes_prioritization':
-            True, 'schemes_tried_regions': False, 'record': False,
-            'schemes_time_quota': True, 'fvaddr': False, 'paddr': True,
-            'schemes_wmarks': True, 'schemes_size_quota': True,
-            'schemes_stat_succ': True, 'vaddr': True}.items():
+            'debugfs/init_regions': True, 'sysfs/init_regions': True,
+            'debugfs/schemes': True, 'sysfs/schemes': True,
+            'debugfs/schemes_stat_qt_exceed': True,
+            'sysfs/schemes_stat_qt_exceed': True,
+            'debugfs/init_regions_target_idx': True,
+            'debugfs/schemes_prioritization': True,
+            'sysfs/schemes_prioritization': True,
+            'sysfs/schemes_tried_regions': False, 'debugfs/record': False,
+            'debugfs/schemes_time_quota': True,
+            'sysfs/schemes_time_quota': True, 'sysfs/fvaddr': False,
+            'debugfs/paddr': True, 'sysfs/paddr': True,
+            'debugfs/schemes_wmarks': True, 'sysfs/schemes_wmarks': True,
+            'debugfs/schemes_size_quota': True,
+            'sysfs/schemes_size_quota': True,
+            'debugfs/schemes_stat_succ': True, 'sysfs/schemes_stat_succ': True,
+            'debugfs/vaddr': True, 'sysfs/vaddr': True,
+            }.items():
         if not support:
             continue
-        for feature in _damo_sysinfo.damon_features:
+        for feature in _damon_features.features_list:
             if feature.name == name:
                 avail_features.append(feature)
     _damo_sysinfo.system_info = _damo_sysinfo.SystemInfo(
             damo_version=None, kernel_version=None,
-            avail_damon_sysfs_features=avail_features,
-            avail_damon_debugfs_features=[])
+            avail_damon_features=avail_features)
 
 class TestDamonArgs(unittest.TestCase):
     def test_damon_ctxs_for(self):
